# eric7.EricWidgets.EricListView

Module implementing specialized list views.

### Global Attributes

None

### Classes

EricListView | Class implementing a list view supporting removal of entries.

### Functions

None

## EricListView

Class implementing a list view supporting removal of entries.

### Derived from

QListView

### Class Attributes

None

### Class Methods

None

### Methods

keyPressEvent | Protected method implementing special key handling.
removeAll | Public method to clear the view.
removeSelected | Public method to remove the selected entries.

### Static Methods

None

#### EricListView.keyPressEvent

keyPressEvent(evt)

Protected method implementing special key handling.

evt (QKeyEvent)
  reference to the event

#### EricListView.removeAll

removeAll()

Public method to clear the view.

#### EricListView.removeSelected

removeSelected()

Public method to remove the selected entries.

Up